<?php
namespace App\Controller;

use App\Controller\AppController;

/**
* Gastos Controller
*
* @property \App\Model\Table\GastosTable $Gastos
*
* @method \App\Model\Entity\Gasto[]|\Cake\Datasource\ResultSetInterface paginate( $object = null, array $settings = [] )
*/

class GastosController extends AppController {
    /**
    * Index method
    *
    * @return \Cake\Http\Response|null
    */

    public function index() {

        $this->paginate = [
            'conditions' => [ 'Gastos.tipgasto' => $id ],
            'order' => [
                'Gastos.id' => 'asc'
            ]
        ];

        $gastos = $this->paginate( $this->Gastos );

        $this->set( compact( 'gastos' ) );
    }

    public function cod( $id = null ) {

        $this->paginate = [
            'conditions' => [ 'Gastos.tipgasto' => $id, 'Gastos.borrado' => 0 ],
            'order' => [
                'Gastos.id' => 'desc'
            ]
        ];

        $gastos = $this->paginate( $this->Gastos );

        $this->set( compact( 'gastos' ) );
    }

    public function codigo( $id = null ) {
        //seleccionar query url de fecha desde y hasta fechah

        if ( $this->request->query[ 'fechah' ] == null || $this->request->query[ 'fechad' ] == null ) {
           
            $this->set( compact( 'gastos' ) );
        } else {

            $desde = $this->request->query[ 'fechah' ];
            $hasta = $this->request->query[ 'fechad' ];


            $fechar = "(to_timestamp(fecha,'dd/MM/yyyy') between to_timestamp('" . str_replace( "-", "/", $desde) . "','dd/MM/yyyy') and to_timestamp('" . str_replace( "-", "/", $hasta) . "','dd/MM/yyyy'))";
        

            $this->paginate = [
                'conditions' => [
                    'Gastos.tipgasto' => $id,
                    'Gastos.borrado' => 0,
                    $fechar

                ],
                'order' => [
                    'Gastos.id' => 'asc'
                ]
            ];

            $gastos = $this->paginate( $this->Gastos );

            $this->set( compact( 'gastos' ) );
            $this->set( 'desde', $desde );
            $this->set( 'hasta', $hasta );
        }
    }

    /**
    * View method
    *
    * @param string|null $id Gasto id.
    * @return \Cake\Http\Response|null
    * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
    */

    public function view( $id = null ) {
        $gasto = $this->Gastos->get( $id, [
            'contain' => [ 'Vehiculo', 'Adelantoschapista' ],
        ] );

        $this->set( 'gasto', $gasto );
    }

    /**
    * Add method
    *
    * @return \Cake\Http\Response|null Redirects on successful add, renders view otherwise.
    */

    public function add() {
        $gasto = $this->Gastos->newEntity();
        if ( $this->request->is( 'post' ) ) {
            $gasto = $this->Gastos->patchEntity( $gasto, $this->request->getData() );
            if ( $this->Gastos->save( $gasto ) ) {
                $this->Flash->success( __( 'Se guardo correctamente!' ) );

                return $this->redirect( [ 'action' => 'index' ] );
            }
            $this->Flash->error( __( 'Error al registrar, intente nuevamente!' ) );
        }
        $vehiculo = $this->Gastos->Vehiculo->find( 'list', [ 'limit' => 200 ] );
        $this->set( compact( 'gasto', 'vehiculo' ) );
    }

    /**
    * Edit method
    *
    * @param string|null $id Gasto id.
    * @return \Cake\Http\Response|null Redirects on successful edit, renders view otherwise.
    * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
    */

    public function edit( $id = null ) {
        $gasto = $this->Gastos->get( $id, [
            'contain' => [ 'Vehiculo' ],
        ] );
        if ( $this->request->is( [ 'patch', 'post', 'put' ] ) ) {
            $gasto = $this->Gastos->patchEntity( $gasto, $this->request->getData() );
            if ( $this->Gastos->save( $gasto ) ) {
                $this->Flash->success( __( 'Modificado correctamente!' ) );

                return $this->redirect( [ 'action' => 'index' ] );
            }
            $this->Flash->error( __( 'Error al modificar, intente de nuevo!' ) );
        }
        $vehiculo = $this->Gastos->Vehiculo->find( 'list', [ 'limit' => 200 ] );
        $this->set( compact( 'gasto', 'vehiculo' ) );
    }

    /**
    * Delete method
    *
    * @param string|null $id Gasto id.
    * @return \Cake\Http\Response|null Redirects to index.
    * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
    */

    public function delete( $id = null ) {
        $this->request->allowMethod( [ 'post', 'delete' ] );
        $gasto = $this->Gastos->get( $id );
        if ( $this->Gastos->delete( $gasto ) ) {
            $this->Flash->success( __( 'Elimando correctamente!' ) );
        } else {
            $this->Flash->error( __( 'Error al eliminar dato, intente de nuevo!' ) );
        }

        return $this->redirect( [ 'action' => 'index' ] );
    }
}
