<?php
namespace App\Controller;

use App\Controller\AppController;
use Cake\ORM\TableRegistry ; 
use Cake\Datasource\ConnectionManager;

/**
 * Liquisalarios Controller
 *
 * @property \App\Model\Table\LiquisalariosTable $Liquisalarios
 *
 * @method \App\Model\Entity\Liquisalario[]|\Cake\Datasource\ResultSetInterface paginate($object = null, array $settings = [])
 */
class LiquisalariosController extends AppController
{
    /**
     * Index method
     *
     * @return \Cake\Http\Response|null
     */
    public function index()
    {
        $liquisalarios = $this->paginate($this->Liquisalarios, 
        [
            'conditions' => [
                'empleadonro' => $this->Auth->User('empleado'),
           ],
           'order' => ['id' => 'desc'] 
            
        ] );

        $this->set(compact('liquisalarios'));
    }

    /**
     * View method
     *
     * @param string|null $id Liquisalario id.
     * @return \Cake\Http\Response|null
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function view($id = null)
    {
        $liquisalario = $this->Liquisalarios->get($id, [
            'contain' => [],
        ]);
        
         $listadodetalles = TableRegistry::get('listadodetalles')->find()
            ->where([
                'liquisalarioid' => $id,
            ]);

        $this->set('liquisalario', $liquisalario);
        
        $this->set('listadodetalles', $listadodetalles);
    }

    /**
     * Add method
     *
     * @return \Cake\Http\Response|null Redirects on successful add, renders view otherwise.
     */
    public function add()
    {
        $liquisalario = $this->Liquisalarios->newEntity();
        if ($this->request->is('post')) {
            $liquisalario = $this->Liquisalarios->patchEntity($liquisalario, $this->request->getData());
            if ($this->Liquisalarios->save($liquisalario)) {
                $this->Flash->success(__('The liquisalario has been saved.'));

                return $this->redirect(['action' => 'index']);
            }
            $this->Flash->error(__('The liquisalario could not be saved. Please, try again.'));
        }
        $this->set(compact('liquisalario'));
    }

    /**
     * Edit method
     *
     * @param string|null $id Liquisalario id.
     * @return \Cake\Http\Response|null Redirects on successful edit, renders view otherwise.
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function edit($id = null)
    {
        $liquisalario = $this->Liquisalarios->get($id, [
            'contain' => [],
        ]);
        if ($this->request->is(['patch', 'post', 'put'])) {
            $liquisalario = $this->Liquisalarios->patchEntity($liquisalario, $this->request->getData());
            if ($this->Liquisalarios->save($liquisalario)) {
                $this->Flash->success(__('The liquisalario has been saved.'));

                return $this->redirect(['action' => 'index']);
            }
            $this->Flash->error(__('The liquisalario could not be saved. Please, try again.'));
        }
        $this->set(compact('liquisalario'));
    }

    /**
     * Delete method
     *
     * @param string|null $id Liquisalario id.
     * @return \Cake\Http\Response|null Redirects to index.
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function delete($id = null)
    {
        $this->request->allowMethod(['post', 'delete']);
        $liquisalario = $this->Liquisalarios->get($id);
        if ($this->Liquisalarios->delete($liquisalario)) {
            $this->Flash->success(__('The liquisalario has been deleted.'));
        } else {
            $this->Flash->error(__('The liquisalario could not be deleted. Please, try again.'));
        }

        return $this->redirect(['action' => 'index']);
    }
}
