<?php
namespace App\Controller;

use App\Controller\AppController;
use Cake\ORM\TableRegistry ; 
use Cake\Datasource\ConnectionManager;

/**
 * Simuladors Controller
 *
 * @property \App\Model\Table\SimuladorsTable $Simuladors
 *
 * @method \App\Model\Entity\simulador[]|\Cake\Datasource\ResultSetInterface paginate($object = null, array $settings = [])
 */
class SimuladorsController extends AppController
{

    /**
     * Index method
     *
     * @return \Cake\Http\Response|void
     */
    public function index()
    {
        $this->paginate = [
            'conditions' => ['stocks.imagen IS NULL'],
            'contain' => ['Stocks', 'Empleados']
        ];

        $Simuladors = $this->paginate($this->Simuladors);

        $this->set(compact('Simuladors'));
    }

    public function movil()
    {
        $condicion = 'Empleados.id = ' .  $this->Auth->User('empleado') ;//. " and fecha = '" .  date('d/m/Y') . "'" ;
        $this->paginate = [
            'conditions' => [$condicion],
            'order' => [
               'simuladors.id' => 'asc'
            ],
            'contain' => ['Stocks', 'Empleados']
            
        ];
        $Simuladors = $this->paginate($this->Simuladors);
        $Bonosdescuentos = TableRegistry::get('bonosdescuentos');
        $bonosdescuento = $Bonosdescuentos->get(1);
        $Comisiones = TableRegistry::get('comisiones');
        $comision = $Comisiones->get(1);
        $tocks  =  TableRegistry::get('cotizacions');
        $query = $tocks->find('all');
        $venta = 0;
        $compra = 0;
        foreach ($query as $coti):
          $venta = $coti->doven;
          $compra = $coti->docom;
        endforeach;

        $this->set('cotiventa', $venta);
        $this->set('coticompra', $compra);
        $this->set(compact('Simuladors'));
        $this->set("bonosdescuento", $bonosdescuento);
        $this->set("comisione", $comision);
    }

    /**
     * View method
     *
     * @param string|null $id Simulador Venta id.
     * @return \Cake\Http\Response|void
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function view($id = null)
    {
        $simulador = $this->Simuladors->get($id, [
            'contain' => ['Stocks', 'Empleados']
        ]);

        $this->set('simulador', $simulador);
    }

    /**
     * Add method
     *
     * @return \Cake\Http\Response|null Redirects on successful add, renders view otherwise.
     */
    public function add()
    {
        $simulador = $this->Simuladors->newEntity();
        if ($this->request->is('post')) {
            $simulador = $this->Simuladors->patchEntity($simulador, $this->request->getData());
            if ($this->Simuladors->save($simulador)) {
                $this->Flash->success(__('The simulador venta has been saved.'));

                return $this->redirect(['action' => 'index']);
            }
            $this->Flash->error(__('The simulador venta could not be saved. Please, try again.'));
        }
        $Stocks = $this->Simuladors->Stocks->find('list', ['limit' => 200]);
        $empleados = $this->Simuladors->Empleados->find('list', ['limit' => 200]);




        $this->set(compact('simulador', 'Stocks', 'empleados'));
    }

    /**
     * Edit method
     *
     * @param string|null $id Simulador Venta id.
     * @return \Cake\Http\Response|null Redirects on successful edit, renders view otherwise.
     * @throws \Cake\Network\Exception\NotFoundException When record not found.
     */
    public function edit($id = null)
    {
        $simulador = $this->Simuladors->get($id, [
            'contain' => []
        ]);
        if ($this->request->is(['patch', 'post', 'put'])) {
            $simulador = $this->Simuladors->patchEntity($simulador, $this->request->getData());
            if ($this->Simuladors->save($simulador)) {
                $this->Flash->success(__('Bono generado correctamente'));

                return $this->redirect(['action' => 'movil']);
            }
            $this->Flash->error(__('Complete todos los campos obligatorios!'));
        }
        $Stocks = $this->Simuladors->Stocks->find('list', ['limit' => 200]);
        $empleados = $this->Simuladors->Empleados->find('list', ['limit' => 200]);
        $this->set(compact('simulador', 'Stocks', 'empleados'));
    }

    /**
     * Delete method
     *
     * @param string|null $id Simulador Venta id.
     * @return \Cake\Http\Response|null Redirects to index.
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function delete($id = null)
    {
        $this->request->allowMethod(['post', 'delete']);
        $simulador = $this->Simuladors->get($id);
        if ($this->Simuladors->delete($simulador)) {
            $this->Flash->success(__('Simulador enviado al gerente!'));
        } else {
            $this->Flash->error(__('The simulador venta could not be deleted. Please, try again.'));
        }

        return $this->redirect(['action' => 'movil']);
    }


    public function gerentebono($id = null)
    {
        $connection = ConnectionManager::get('default');
        $connection->execute('UPDATE simuladors SET estado=? WHERE id=?', [1, $id]);
                
        $connection->commit();
        $connection->disconnect();
         return $this->redirect(['action' => 'movil']);
    }


    public function rechazarbono($id = null)
    {
        $connection = ConnectionManager::get('default');
        $connection->execute('UPDATE simuladors SET estado=? WHERE id=?', [3, $id]);
                
        $connection->commit();
        $connection->disconnect();
         return $this->redirect(['action' => 'listado2gerente']);
    }


    public function confirmarventa($id = null)
    {
        $connection = ConnectionManager::get('default');
        $connection->execute('UPDATE simuladors SET confirmado=? WHERE id=?', [1, $id]);
                
        $connection->commit();
        $connection->disconnect();
         return $this->redirect(['action' => 'movil']);
    }


    public function gerente2bono($id = null)
    {
        $connection = ConnectionManager::get('default');
        $connection->execute('UPDATE simuladors SET estado=? WHERE id=?', [2, $id]);
                
        $connection->commit();
        $connection->disconnect();
         return $this->redirect(['action' => 'listadogerente']);
    }


    public function listadogerente($empresa = null) 
    {
        $condicion = 'Empleados.empresa = ' .  $empresa . " AND Simuladors.estado = 1 " ;
        $this->paginate = [
            'conditions' => [$condicion],
            'order' => [
               'simuladors.id' => 'asc'
            ],
            'contain' => ['Stocks', 'Empleados']
        ];
        $Simuladors = $this->paginate($this->Simuladors);
        $Bonosdescuentos = TableRegistry::get('bonosdescuentos');
        $bonosdescuento = $Bonosdescuentos->get(1);
        $Comisiones = TableRegistry::get('comisiones');
        $comision = $Comisiones->get(1);
        $tocks  =  TableRegistry::get('cotizacions');
        $query = $tocks->find('all');
        $venta = 0;
        $compra = 0;
        foreach ($query as $coti):
          $venta = $coti->doven;
          $compra = $coti->docom;
        endforeach;
        $this->set('cotiventa', $venta);
        $this->set('coticompra', $compra);
        $this->set(compact('Simuladors'));
        $this->set("bonosdescuento", $bonosdescuento);
        $this->set("comisione", $comision);
    }


    public function agregarbono($id = null)
    {
      $simulador = $this->Simuladors->get($id);
      if ($this->request->is(['patch', 'post', 'put'])) {
          $simulador = $this->Simuladors->patchEntity($simulador, $this->request->getData());
          $simulador->totalbono = $simulador->totalbono + $simulador->aumentabonogerente;
          $simulador->veces = $simulador->veces + 1;
          $simulador->estado = 3;
          if ($this->Simuladors->save($simulador)) {
             return $this->redirect(['action' => 'listado2gerente']);
          }
          $this->Flash->error(('Complete todos los campos!'));
      }
    }



    public function listado2gerente() 
    {
        $condicion = "Simuladors.estado = 2 " ;
        $this->paginate = [
            'conditions' => [$condicion],
            'order' => [
               'simuladors.id' => 'asc'
            ],
            'contain' => ['Stocks', 'Empleados']
        ];
        $Simuladors = $this->paginate($this->Simuladors);
        $Bonosdescuentos = TableRegistry::get('bonosdescuentos');
        $bonosdescuento = $Bonosdescuentos->get(1);
        $Comisiones = TableRegistry::get('comisiones');
        $comision = $Comisiones->get(1);
        $tocks  =  TableRegistry::get('cotizacions');
        $query = $tocks->find('all');
        $venta = 0;
        $compra = 0;
        foreach ($query as $coti):
          $venta = $coti->doven;
          $compra = $coti->docom;
        endforeach;
        $this->set('cotiventa', $venta);
        $this->set('coticompra', $compra);
        $this->set(compact('Simuladors'));
        $this->set("bonosdescuento", $bonosdescuento);
        $this->set("comisione", $comision);
    }


    public function listado2gerente() 
    {
        $condicion = "Simuladors.confirmar = 1 " ;
        $this->paginate = [
            'conditions' => [$condicion],
            'order' => [
               'simuladors.id' => 'asc'
            ],
            'contain' => ['Stocks', 'Empleados']
        ];
        $Simuladors = $this->paginate($this->Simuladors);
        $Bonosdescuentos = TableRegistry::get('bonosdescuentos');
        $bonosdescuento = $Bonosdescuentos->get(1);
        $Comisiones = TableRegistry::get('comisiones');
        $comision = $Comisiones->get(1);
        $tocks  =  TableRegistry::get('cotizacions');
        $query = $tocks->find('all');
        $venta = 0;
        $compra = 0;
        foreach ($query as $coti):
          $venta = $coti->doven;
          $compra = $coti->docom;
        endforeach;
        $this->set('cotiventa', $venta);
        $this->set('coticompra', $compra);
        $this->set(compact('Simuladors'));
        $this->set("bonosdescuento", $bonosdescuento);
        $this->set("comisione", $comision);
    }

    public function ver($id = null)
    {
        $condicion = 'Empleados.id = ' .  $this->Auth->User('empleado') . ' and Simuladors.id =' .$id ;//. " and fecha = '" .  date('d/m/Y') . "'" ;
        $this->paginate = [
            'conditions' => [$condicion],
            'order' => [
               'Simuladors.id' => 'asc'
            ],
            'contain' => ['Stocks', 'Empleados']
            
        ];
        $Simuladors = $this->paginate($this->Simuladors);
        $Bonosdescuentos = TableRegistry::get('bonosdescuentos');
        $bonosdescuento = $Bonosdescuentos->get(1);
        $Comisiones = TableRegistry::get('comisiones');
        $comision = $Comisiones->get(1);
        $tocks  =  TableRegistry::get('cotizacions');
        $query = $tocks->find('all');
        $venta = 0;
        $compra = 0;
        foreach ($query as $coti):
          $venta = $coti->doven;
          $compra = $coti->docom;
        endforeach;

        $this->set('cotiventa', $venta);
        $this->set('coticompra', $compra);
        $this->set(compact('Simuladors'));
        $this->set("bonosdescuento", $bonosdescuento);
        $this->set("comisione", $comision);
    }

}